# pyrepo-mcda

The Python 3 library for Multi-Criteria Decision Analysis. Documentation of this library with instruction of installation and usage is 
provided [here](https://pyrepo-mcda.readthedocs.io/en/latest/)